import type { HyperConstructor, HyperRaw, HyperVal } from '../Hyper';
import { Hyper } from '../Hyper';
export declare class HyperAugment<T extends Hyper<any, any>> extends Hyper<HyperRaw<T>, HyperVal<T>> {
    /** Unaugment schema */
    readonly schema: T;
    constructor(
    /** Unaugment schema */
    schema: T, ...hyper: HyperConstructor<HyperVal<T>>);
}
/**
 * Add an augment function to be used on a Hyper
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param augment Function to augment result.
 * @returns `(test: Test<T>) => Test<U>` Curried test callback.
 */
export declare function augment<T extends Hyper<any>>(augment: (tested: HyperVal<T>) => boolean): 
/**
 * Augment the checking of a value after the initial test.
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param hyper Function to augment result.
 * @returns `Test<U>` The resulting test.
 */
(hyper: T) => HyperAugment<T>;
/**
 * Augment the checking of a value after the initial test.
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param hyper Function to augment result.
 * @param augment `Test<T>` Test to use before augmentation.
 * @returns `Test<U>` The resulting test.
 */
export declare function augment<T extends Hyper<any, any>>(hyper: T, augment: (tested: HyperVal<T>) => boolean): HyperAugment<T>;
